@@ -1,3 +1,4 @@
+import time
 from threading import Thread
 from typing import (
     Callable,
@@ -63,6 +64,7 @@ class Future(MonadInterface[A]):
             on_start: Optional[CallbackInterface] = None,
             on_complete: Optional[CallbackInterface] = None,
             parent_id: Optional[str] = None,
+            broadcast: bool = False,
             **kwargs
         ):
         """Initializes a Future with the provided function to be executed asynchronously.
@@ -77,7 +79,11 @@ class Future(MonadInterface[A]):
                 All keyword arguments except 'future_id' are forwarded to the target function.
         """
         # Create a new available future
-        future = FutureUndefinedPending.auto(parent_id=parent_id, future_id=kwargs.pop("future_id", None))
+        future = FutureUndefinedPending.auto(
+            parent_id=parent_id,
+            broadcast=broadcast,
+            future_id=kwargs.pop("future_id", None),
+        )
         # Register the Future-ID and define the available future via the provided function.
         # Note: The 'apply' method is blocking by itself; thus, we run it in a separate thread.
         # Note: The thread is a daemon to ensure it does not block program exit.
@@ -199,8 +205,22 @@ class Future(MonadInterface[A]):
         return self.wait(timeout=timeout).resolve()
 
     @classmethod
-    def from_value(cls, val: A) -> 'Future[A]':
-        return Future(function=lambda: val)
+    def from_value(cls, val: A, **kwargs) -> 'Future[A]':
+        """
+        Creates a Future that is immediately resolved with the given value.
+
+        Args:
+            val (A): The value to resolve the Future with.
+            **kwargs: Additional keyword arguments forwarded to the Future constructor.
+                These may include parameters such as:
+                    - parent_id (Optional[str]): The parent future's ID.
+                    - expiration (Optional[float]): Expiration time for the future.
+                    - callback (Optional[CallbackInterface]): Callback to invoke on completion.
+                For a full list of accepted parameters, see the Future class documentation.
+        Returns:
+            Future[A]: A Future instance resolved with the provided value.
+        """
+        return Future(function=lambda: val, **kwargs)
     
     def flat_map(self, function: Callable[[A], 'Future[B]'], timeout: Optional[float] = None) -> 'Future[B]':
         """Chains the current future with another future-producing function.
@@ -276,6 +296,10 @@ class Future(MonadInterface[A]):
         Returns:
             Future[A]: A Future instance representing the pulled future.
         """
+        logger.warning(
+            "The 'pullsync' method is scheduled for deprecation and will be removed in future versions. "
+            "Please use the 'subscribe' method instead that uses a pubsub mechanism."
+        )
         from fred.future.utils import pull_future_result
 
         return cls(
@@ -289,6 +313,87 @@ class Future(MonadInterface[A]):
             on_complete=on_complete,
             **kwargs
         )
+
+    @classmethod
+    def subscribe(
+            cls,
+            future_id: str,
+            on_start: Optional[CallbackInterface] = None,
+            on_complete: Optional[CallbackInterface] = None,
+            retry_delay: float = 0.2,
+            retry: int = 3,
+    ) -> 'Future[A]':
+        """Subscribes to updates for an existing future using a publish-subscribe mechanism.
+        This method allows for receiving real-time updates about the future's state
+        and result without blocking.
+        Args:
+            future_id (str): The unique identifier of the future to subscribe to.
+            on_start (Optional[CallbackInterface]): An optional callback to be executed
+                                                   when the subscription starts.
+            on_complete (Optional[CallbackInterface]): An optional callback to be executed
+                                                      when the future completes.
+        Returns:
+            Future[A]: A Future instance that will execute the subscription logic.
+        """
+        # TODO: Consider adding a timeout parameter to avoid waiting indefinitely...
+        # TODO: There's a known issue where if the future completes before we subscribe,
+        #       we might miss the completion message.
+        # Define a closure that will handle incoming messages from the pub-sub channel
+        def closure():
+            for payload in FutureResult._get_bcast_channel(future_id=future_id).subscribe():
+                logger.info(f"Received pubsub message for future '{future_id}': {payload}")
+                if payload.get("type") != "message":
+                    continue
+                message = payload.get("data")
+                if not message:
+                    continue
+                match FutureResult.from_string(message):
+                    case FutureDefined(value=value):
+                        return value.resolve()
+                    case FutureUndefinedPending():
+                        continue
+                    case FutureUndefinedInProgress():
+                        continue
+                    case _:
+                        raise TypeError("Unknown FutureResult type")
+        shared_params = {
+            "parent_id": future_id,
+            "broadcast": False,
+            "on_start": on_start,
+            "on_complete": on_complete,
+        }
+        # Depending on the current state of the future, either return the resolved value
+        # or subscribe to the broadcast channel to wait for updates (via closure).
+        match FutureResult.from_backend(future_id=future_id):
+            case FutureDefined(value=value):
+                return cls(
+                    function=lambda: value.resolve(),
+                    **shared_params
+                )
+            case instance:
+                # The future-result can be None if the future_id does not exist
+                if not instance:
+                    if retry <= 0:
+                        raise ValueError(f"Future with ID '{future_id}' does not exist.")
+                    logger.error(f"Future with ID '{future_id}' does not exist; attempting to retry ({retry} retries left).")
+                    time.sleep(retry_delay)
+                    return cls.subscribe(
+                        future_id=future_id,
+                        on_start=on_start,
+                        on_complete=on_complete,
+                        retry_delay=retry_delay,
+                        retry=max(0, retry - 1),
+                    )
+                # If the future exists, but is not configured for broadcast, raise an error...
+                if not instance.broadcast:
+                    raise ValueError("Future is not configured for broadcast; cannot subscribe.")
+                # If the future exists and is configured for broadcast, subscribe to updates...
+                logger.info(f"Subscribing to future '{future_id}' via broadcast channel.")
+                return cls(
+                    function=closure,
+                    **shared_params
+                )
+
     def lineage(self) -> list[str]:
         """Retrieves the lineage of the future, tracing back through its parent futures.
         This method is useful for debugging and understanding the sequence of computations
