@@ -14,14 +14,14 @@ class RunnerStatus(Enum):
     @staticmethod
     def get_key(runner_id: str) -> str:
         """Get the status key for the specified runner ID."""
-        return f"runner:status:{runner_id}"
+        return f"frd:runner:{runner_id}"
     
-    def get_val(self, *include) -> str:
+    def get_val(self, queue_slug: str, *include) -> str:
         """Get the string representation of the status."""
-        return ":".join([self.name, datetime_utcnow().isoformat(), *include]) 
+        return ":".join([queue_slug, self.name, datetime_utcnow().isoformat(), *include]) 
     
     @classmethod
-    def parse_value(cls, value: str) -> "RunnerStatus":
+    def parse_value(cls, value: str) -> tuple[str, "RunnerStatus"]:
         """Parse the status from the stored value."""
-        val, *_ = value.split(":")
-        return cls[val.upper()]
+        queue_slug, status, *_ = value.split(":")
+        return (queue_slug, cls[status.upper()])
